from rand_pass_generator import generate

def testFunction():
    assert type(generate()) == dict
